import { AfterViewInit, ElementRef, EventEmitter, Injector, OnDestroy, OnInit } from '@angular/core';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { ActivatedRoute, ActivatedRouteSnapshot, Router } from '@angular/router';
import { Observable, Subscription } from 'rxjs';
import { ILayoutManagerComponent } from '../../interfaces/layout-manager-component.interface';
import { ILocalStorageComponent } from '../../interfaces/local-storage-component.interface';
import { OFormLayoutManagerMode } from '../../interfaces/o-form-layout-manager-mode.interface';
import { LocalStorageService } from '../../services/local-storage.service';
import { NavigationService } from '../../services/navigation.service';
import { OFormLayoutManagerService } from '../../services/o-form-layout-manager.service';
import { OFormLayoutManagerComponentStateClass } from '../../services/state/o-form-layout-manager-component-state.class';
import { OFormLayoutManagerComponentStateService } from '../../services/state/o-form-layout-manager-component-state.service';
import { OTranslateService } from '../../services/translate/o-translate.service';
import { FormLayoutCloseDetailOptions, FormLayoutDetailComponentData } from '../../types/form-layout-detail-component-data.type';
import { OFormLayoutDialogComponent } from './dialog/o-form-layout-dialog.component';
import { OFormLayoutManagerBase } from './o-form-layout-manager-base.class';
import { OFormLayoutManagerContext } from '../../types/form-layout-manager-context.type';
import { IOFormLayoutManager } from '../../interfaces/form-layout-manager.interface';
import * as i0 from "@angular/core";
export declare const DEFAULT_INPUTS_O_FORM_LAYOUT_MANAGER: string[];
export declare const DEFAULT_OUTPUTS_O_FORM_LAYOUT_MANAGER: string[];
export declare class OFormLayoutManagerComponent implements AfterViewInit, OnInit, OnDestroy, ILocalStorageComponent, IOFormLayoutManager {
    protected injector: Injector;
    protected router: Router;
    protected actRoute: ActivatedRoute;
    protected dialog: MatDialog;
    protected elRef: ElementRef;
    parentFormLayoutManager: OFormLayoutManagerBase;
    OFormLayoutManagerComponent: typeof OFormLayoutManagerComponent;
    static DIALOG_MODE: string;
    static TAB_MODE: string;
    static SPLIT_PANE_MODE: string;
    oattr: string;
    _mode: string;
    stretchTabs: boolean;
    get mode(): string;
    set mode(value: string);
    protected _separator: string;
    set separator(value: string);
    get separator(): string;
    title: string;
    storeState: boolean;
    titleDataOrigin: string;
    dialogWidth: string;
    dialogMinWidth: string;
    dialogMaxWidth: string;
    dialogHeight: string;
    dialogMinHeight: string;
    dialogMaxHeight: string;
    dialogClass: string;
    dialogTitleSeparator: string;
    oTabGroup: OFormLayoutManagerMode;
    dialogRef: MatDialogRef<OFormLayoutDialogComponent>;
    oSplitPane: OFormLayoutManagerMode;
    onMainTabSelected: EventEmitter<any>;
    onSelectedTabChange: EventEmitter<any>;
    onCloseTab: EventEmitter<any>;
    protected _labelColumns: string;
    get labelColumns(): string;
    set labelColumns(value: string);
    protected _labelColsArray: string[];
    get labelColsArray(): string[];
    set labelColsArray(value: string[]);
    protected translateService: OTranslateService;
    protected oFormLayoutManagerService: OFormLayoutManagerService;
    protected localStorageService: LocalStorageService;
    protected _tabGroupOptions: any;
    get tabGroupOptions(): any;
    addTabGroupOptions(value: any): void;
    protected _dialogOptions: any;
    get dialogOptions(): any;
    addDialogOptions(value: any): void;
    protected _splitPaneOptions: any;
    get splitPaneOptions(): any;
    addSplitPaneOptions(value: any): void;
    protected addingGuard: boolean;
    navigationService: NavigationService;
    _markForUpdate: boolean;
    onTriggerUpdate: EventEmitter<any>;
    protected subscription: Subscription;
    protected componentStateService: OFormLayoutManagerComponentStateService;
    constructor(injector: Injector, router: Router, actRoute: ActivatedRoute, dialog: MatDialog, elRef: ElementRef, parentFormLayoutManager: OFormLayoutManagerBase);
    private getInjectionTokenConfig;
    get state(): OFormLayoutManagerComponentStateClass;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    getAttribute(): string;
    getComponentKey(): string;
    getRouteKey(): string;
    getDataToStore(): any;
    beforeunloadHandler(): void;
    getLabelFromUrlParams(urlParams: object): string;
    getFormDataFromLabelColumns(data: any): {};
    addActivateChildGuard(): void;
    destroyActivateChildGuard(): void;
    isDialogMode(): boolean;
    isTabMode(): boolean;
    isSplitPaneMode(): boolean;
    addDetailComponent(childRoute: ActivatedRouteSnapshot, url: string, context?: OFormLayoutManagerContext): void;
    closeDetail(options?: FormLayoutCloseDetailOptions): void;
    closeDetails(detailsData?: any[], options?: FormLayoutCloseDetailOptions): void;
    openFormLayoutDialog(detailComp: FormLayoutDetailComponentData): void;
    getFormCacheData(): FormLayoutDetailComponentData;
    setModifiedState(formAttr: string, modified: boolean, confirmExit: boolean): void;
    getLabelFromData(data: any): string;
    updateNavigation(data: any, keysValues: any, insertionMode: boolean): void;
    updateActiveData(data: any): void;
    getRouteOfActiveItem(): any[];
    isMainComponent(comp: ILayoutManagerComponent): boolean;
    getRouteForComponent(comp: ILayoutManagerComponent): any[];
    setAsActiveFormLayoutManager(): void;
    reloadMainComponents(): void;
    allowToUpdateNavigation(formAttr: string): boolean;
    updateStateStorage(): void;
    private getParentActRouteRoute;
    updateIfNeeded(): void;
    getParams(): any;
    set markForUpdate(arg: boolean);
    get markForUpdate(): boolean;
    get ignoreCanDeactivate(): boolean;
    protected getLayoutModeComponent(): OFormLayoutManagerMode;
    allowNavigation(): boolean;
    canAddDetailComponent(): Observable<boolean>;
    hasToConfirmExit(data: FormLayoutDetailComponentData, options?: FormLayoutCloseDetailOptions): boolean;
    getIdOfActiveItem(): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<OFormLayoutManagerComponent, [null, null, null, null, null, { optional: true; skipSelf: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<OFormLayoutManagerComponent, "o-form-layout-manager", never, { "oattr": "attr"; "mode": "mode"; "storeState": "store-state"; "title": "title"; "labelColumns": "label-columns"; "separator": "separator"; "titleDataOrigin": "title-data-origin"; "dialogWidth": "dialog-width"; "dialogMinWidth": "dialog-min-width"; "dialogMaxWidth": "dialog-max-width"; "dialogHeight": "dialog-height"; "dialogMinHeight": "dialog-min-height"; "dialogMaxHeight dialog-max-height": "dialogMaxHeight dialog-max-height"; "dialogClass": "dialog-class"; "dialogTitleSeparator": "dialog-title-separator"; }, { "onMainTabSelected": "onMainTabSelected"; "onSelectedTabChange": "onSelectedTabChange"; "onCloseTab": "onCloseTab"; }, never, ["*", "*", "*", "*"], false, never>;
}
